==> nextcloud-28.0.8.tgz: nextcloud/apps/weather_status/l10n/vi.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Địa chỉ không xác định",
    "No result." : "Không có kết quả",
    "Error" : "Lỗi",
    "Weather status" : "Tình trạng thời tiết",
    "Weather status in your dashboard" : "Tình trạng thời tiết trên bảng điều khiển của bạn",
    "Weather status integrated in the Dashboard app.\n    The geographic location can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Tình trạng thời tiết được tích hợp trong ứng dụng Dashboard.\nVị trí địa lý có thể được xác định tự động hoặc được xác định thủ công. Một dự báo 6 giờ sẽ được hiển thị.\nTình trạng này cũng có thể được tích hợp vào các nơi khác như ứng dụng Lịch.",
    "Detect location" : "Phát hiện vị trí",
    "Set custom address" : "Cài đặt vị trí tuỳ chọn",
    "Favorites" : "Ưa thích",
    "{temperature} {unit} clear sky later today" : "Trời quang đãng vào cuối ngày hôm nay",
    "{temperature} {unit} clear sky" : "{temperature} {unit} trời quang",
    "{temperature} {unit} cloudy later today" : "Trời nhiều mây vào cuối ngày hôm nay",
    "{temperature} {unit} cloudy" : "{temperature} {unit} nhiều mây",
    "{temperature} {unit} foggy" : "{temperature} {unit} sương mù",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} mưa nhẹ",
    "More weather for {adr}" : "Thêm thông tin thời tiết cho {adr}",
    "Loading weather" : "Đang tải thông tin thời tiết",
    "Remove from favorites" : "Xóa khỏi ưa thích",
    "Add as favorite" : "Thêm vào yêu thích",
    "You are not logged in." : "Bạn chưa đăng nhập",
    "There was an error getting the weather status information." : "Đã xảy ra lỗi khi lấy thông tin tình trạng thời tiết.",
    "No weather information found" : " Không tìm thấy thông tin thời tiết.",
    "Location not found" : "Không tìm thấy vị trí",
    "There was an error setting the location address." : "Đã xảy ra lỗi khi thiết lập địa chỉ vị trí.",
    "There was an error setting the location." : "Đã xảy ra lỗi khi thiết lập vị trí.",
    "There was an error saving the mode." : "Đã xảy ra lỗi khi lưu chế độ.",
    "There was an error using personal address." : "Có lỗi khi sử dụng địa chỉ cá nhân.",
    "Set location for weather" : "Chọn vị trí cho thời tiết",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Trạng thái thời tiết được tích hợp trong ứng dụng Bảng điều khiển.\nVị trí của người dùng có thể tự động xác định hoặc được xác định thủ công. Dự báo 6 giờ sau được hiển thị.\nTrạng thái này cũng có thể được tích hợp vào các nơi khác như ứng dụng Lịch."
},
"nplurals=1; plural=0;");

==> nextcloud-28.0.9.tgz: nextcloud/apps/weather_status/l10n/vi.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Địa chỉ không xác định",
    "No result." : "Không có kết quả",
    "Error" : "Lỗi",
    "Weather status" : "Tình trạng thời tiết",
    "Weather status in your dashboard" : "Tình trạng thời tiết trên bảng điều khiển của bạn",
    "Weather status integrated in the Dashboard app.\n    The geographic location can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Tình trạng thời tiết được tích hợp trong ứng dụng Dashboard.\nVị trí địa lý có thể được xác định tự động hoặc được xác định thủ công. Một dự báo 6 giờ sẽ được hiển thị.\nTình trạng này cũng có thể được tích hợp vào các nơi khác như ứng dụng Lịch.",
    "Detect location" : "Phát hiện vị trí",
    "Set custom address" : "Cài đặt vị trí tuỳ chọn",
    "Favorites" : "Ưa thích",
    "{temperature} {unit} clear sky later today" : "Trời quang đãng vào cuối ngày hôm nay",
    "{temperature} {unit} clear sky" : "{temperature} {unit} trời quang",
    "{temperature} {unit} cloudy later today" : "Trời nhiều mây vào cuối ngày hôm nay",
    "{temperature} {unit} cloudy" : "{temperature} {unit} nhiều mây",
    "{temperature} {unit} fair weather later today" : "{temperature}{unit}thời tiết đẹp vào cuối ngày hôm nay",
    "{temperature} {unit} fair weather" : "{temperature}{unit}thời tiết đẹp",
    "{temperature} {unit} partly cloudy later today" : "{temperature}{unit}có mây rải rác vào cuối ngày hôm nay",
    "{temperature} {unit} partly cloudy" : "{temperature}{unit}có mây rải rác",
    "{temperature} {unit} foggy later today" : "{temperature}{unit}sương mù vào cuối ngày hôm nay",
    "{temperature} {unit} foggy" : "{temperature} {unit} sương mù",
    "{temperature} {unit} light rainfall later today" : "{temperature}{unit}mưa nhẹ vào cuối ngày hôm nay",
    "{temperature} {unit} light rainfall" : "{temperature} {unit} mưa nhẹ",
    "{temperature} {unit} rainfall later today" : "{temperature}{unit}mưa vào cuối ngày hôm nay",
    "{temperature} {unit} rainfall" : "{temperature}{unit}mưa",
    "{temperature} {unit} heavy rainfall later today" : "{temperature}{unit}mưa lớn vào cuối ngày hôm nay",
    "{temperature} {unit} heavy rainfall" : "{temperature}{unit}mưa lớn",
    "{temperature} {unit} rainfall showers later today" : "{temperature}{unit}có mưa rào vào cuối ngày hôm nay",
    "{temperature} {unit} rainfall showers" : "{temperature}{unit}mưa rào",
    "{temperature} {unit} light rainfall showers later today" : "{temperature}{unit}mưa rào nhẹ vào cuối ngày hôm nay",
    "{temperature} {unit} light rainfall showers" : "{temperature}{unit}mưa rào nhẹ",
    "{temperature} {unit} heavy rainfall showers later today" : "{temperature}{unit}mưa rào lớn vào cuối ngày hôm nay",
    "{temperature} {unit} heavy rainfall showers" : "{temperature}{unit}Mưa rào lớn",
    "More weather for {adr}" : "Thêm thông tin thời tiết cho {adr}",
    "Loading weather" : "Đang tải thông tin thời tiết",
    "Remove from favorites" : "Xóa khỏi ưa thích",
    "Add as favorite" : "Thêm vào yêu thích",
    "You are not logged in." : "Bạn chưa đăng nhập",
    "There was an error getting the weather status information." : "Đã xảy ra lỗi khi lấy thông tin tình trạng thời tiết.",
    "No weather information found" : " Không tìm thấy thông tin thời tiết.",
    "Location not found" : "Không tìm thấy vị trí",
    "There was an error setting the location address." : "Đã xảy ra lỗi khi thiết lập địa chỉ vị trí.",
    "There was an error setting the location." : "Đã xảy ra lỗi khi thiết lập vị trí.",
    "There was an error saving the mode." : "Đã xảy ra lỗi khi lưu chế độ.",
    "There was an error using personal address." : "Có lỗi khi sử dụng địa chỉ cá nhân.",
    "Set location for weather" : "Chọn vị trí cho thời tiết",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Trạng thái thời tiết được tích hợp trong ứng dụng Bảng điều khiển.\nVị trí của người dùng có thể tự động xác định hoặc được xác định thủ công. Dự báo 6 giờ sau được hiển thị.\nTrạng thái này cũng có thể được tích hợp vào các nơi khác như ứng dụng Lịch."
},
"nplurals=1; plural=0;");
